/*
 * (C) Copyright 2021 Boni Garcia (https://bonigarcia.github.io/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package io.github.bonigarcia.webdriver.testng.ch06.cloud_providers;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.Assumptions.assumeThat;

import java.net.MalformedURLException;
import java.net.URL;

import org.openqa.selenium.WebDriver;
import org.openqa.selenium.remote.DesiredCapabilities;
import org.openqa.selenium.remote.RemoteWebDriver;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

public class LambdaTestNGTest {

    WebDriver driver;

    @BeforeMethod
    public void setup() throws MalformedURLException {
        String username = System.getProperty("lambdaTestUsername");
        String accessKey = System.getProperty("lambdaTestAccessKey");

        // Innym sposobem odczytania nazwy użytkownika i klucza jest skorzystanie ze zmiennych środowiskowych:
        // String username = System.getenv("LAMBDATEST_USERNAME");
        // String accessKey = System.getenv("LAMBDATEST_ACCESS_KEY");

        assumeThat(username).isNotEmpty();
        assumeThat(accessKey).isNotEmpty();

        DesiredCapabilities capabilities = new DesiredCapabilities();
        capabilities.setCapability("browserName", "Chrome");
        capabilities.setCapability("browserVersion", "70.0");
        capabilities.setCapability("platformName", "win10");
        capabilities.setCapability("build", "My build name");
        capabilities.setCapability("name", "My test name");

        URL remoteUrl = new URL(String.format(
                "http://%s:%s@hub.lambdatest.com/wd/hub", username, accessKey));
        driver = new RemoteWebDriver(remoteUrl, capabilities);
    }

    @AfterMethod
    public void teardown() {
        if (driver != null) {
            driver.quit();
        }
    }

    @Test
    public void testLambdaTest() {
        driver.get("https://bonigarcia.dev/selenium-webdriver-java/");
        assertThat(driver.getTitle()).contains("Selenium WebDriver");
    }

}
